@@ -19,13 +19,15 @@ The text in $sovix__page__copyright doesn't apply to this file, but
 rather to the pages it generates. */
 
 $sovix__page__copyright="Copyright (C) 2006, 2007, 2008 David Englund.
-This entire article is distributed under the GNU Free Documentation
-License, Version 1.2 or any later version.";
+Permission is granted to copy, distribute and/or modify this document
+under the terms of the GNU Free Documentation License, Version 1.2 or any
+later version published by the Free Software Foundation; with no Invariant
+Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
 $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
 $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
 require_once "$sovix__directory__src/header.inc"; ?>
 
-<abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> wesite revision system version 0.0.1.5 is Copyright (C) 2006, 2007, 2008 David Englund.
+<abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> wesite revision system version 0.0.1.6 is Copyright (C) 2006, 2007, 2008 David Englund.
 
 <p></p>
 <h3><?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> Affero General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?></h3>
