@@ -1,24 +1,26 @@
-<?php $sovix__copyright="Copyright (C) 2008 <year> <name of author>.
-This entire article is distributed under the GNU Free Documentation 
-License, Version 1.2 or any later version. The software code in this
-file is distributed under the GNU Affero General Public License,
-Version 3 or any later version.";
+<?php /* Copyright (C) <year> <name of author>.
 
-$sovix__copyright_pointer="This file is part of <name of software>.
-
-This software is free software: you can redistribute it and/or modify
+This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
 published by the Free Software Foundation, either version 3 of the
 License, or (at your option) any later version.
 
-This software is distributed in the hope that it will be useful,
+This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.
 
 You should have received a copy of the GNU Affero General Public License
-along with This software.  If not, see <http://www.gnu.org/licenses/>.";
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+The text in $sovix__page__copyright doesn't apply to this file, but
+rather to the pages it generates. */
+
+$sovix__page__copyright="Copyright (C) <year> <name of author>.
+Permission is granted to copy, distribute and/or modify this document
+under the terms of the GNU Free Documentation License, Version 1.2 or any
+later version published by the Free Software Foundation; with no Invariant
+Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
 $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
 $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/Sandbox/include/dotsovix";
 require_once "$sovix__directory__src/header.inc"; ?>
